[![CI](https://github.com/pangeo-fish/pangeo-fish/actions/workflows/ci.yml/badge.svg?branch=main&event=push)](https://github.com/pangeo-fish/pangeo-fish/actions/workflows/ci.yml)
[![docs](https://readthedocs.org/projects/pangeo-fish/badge/?version=latest)](https://pangeo-fish.readthedocs.io/en/latest/)
[![PyPI version](https://img.shields.io/pypi/v/pangeo-fish.svg)](https://pypi.org/project/pangeo-fish)
[![codestyle](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)

# Pangeo-Fish 🐟

**Pangeo-Fish** is an open, community-driven project designed to leverage the power of the Pangeo ecosystem specifically for fish biologging data analysis and related oceanographic research. The project facilitates scalable, reproducible, and collaborative research by integrating biologging data with environmental datasets using cloud-native technologies.

## 🌊 Project Goals

- **Simplify Biologging Data Analysis:** Integrate and streamline analyses of diverse fish biologging datasets with oceanographic and environmental data.
- **Leverage Cloud Infrastructure:** Utilize Pangeo technologies such as Xarray, Dask, and Jupyter to perform large-scale, efficient computations.
- **Promote Collaboration:** Foster an inclusive community where researchers and developers can share expertise, resources, and innovative tools.

## 🚀 Quick Start

Install directly from PyPI:

```bash
pip install pangeo-fish
```

Or set up the development environment:

```bash
git clone https://github.com/pangeo-fish/pangeo-fish.git
cd pangeo-fish
conda env create -n pangeo-fish -f environment.yml
conda activate pangeo-fish
jupyter lab
```

Explore example notebooks located in the [`notebooks`](https://github.com/pangeo-fish/pangeo-fish/tree/main/notebooks) directory.

## 📖 Documentation

Complete documentation, including guides, tutorials, and examples, is available on [Read the Docs](https://pangeo-fish.readthedocs.io/en/latest/).

Topics include:

- Data ingestion and preprocessing
- Integration of biologging and environmental datasets
- Scalable computing with Dask and Xarray
- Visualization techniques for biologging data

## 🤝 Contributing

We warmly welcome contributions! You can contribute by:

- Reporting bugs and suggesting enhancements via [GitHub Issues](https://github.com/pangeo-fish/pangeo-fish/issues).
- Joining discussions on our [GitHub Discussions](https://github.com/pangeo-fish/pangeo-fish/discussions).
- Submitting code improvements or new features through Pull Requests.

For detailed guidelines, please refer to our [contribution guidelines](https://github.com/pangeo-fish/pangeo-fish/blob/main/CONTRIBUTING.md).

## 📜 License

Pangeo-Fish is distributed under the [BSD 3-Clause License](https://github.com/pangeo-fish/pangeo-fish/blob/main/LICENSE).

---

🌐 **Join us to advance open, scalable science through biologging data analysis!**
